@@ -26,31 +26,63 @@
 
 This AWS Solutions Construct implements an AWS Lambda function connected to an Amazon EventBridge.
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition:
+
+Typescript
 
 ```python
+import { Construct } from 'constructs';
+import { Stack, StackProps, Aws } from 'aws-cdk-lib';
 import { LambdaToEventbridge, LambdaToEventbridgeProps } from "@aws-solutions-constructs/aws-lambda-eventbridge";
+import * as lambda from 'aws-cdk-lib/aws-lambda';
 
 new LambdaToEventbridge(this, 'LambdaToEventbridgePattern', {
-    lambdaFunctionProps: {
-        runtime: lambda.Runtime.NODEJS_14_X,
-        handler: 'index.handler',
-        code: lambda.Code.fromAsset(`${__dirname}/lambda`)
-    }
+  lambdaFunctionProps: {
+    runtime: lambda.Runtime.NODEJS_14_X,
+    handler: 'index.handler',
+    code: lambda.Code.fromAsset(`lambda`)
+  }
 });
 ```
 
-## Initializer
+Python
 
-```text
-new LambdaToEventbridge(scope: Construct, id: string, props: LambdaToEventbridgeProps);
+```python
+from aws_solutions_constructs.aws_lambda_eventbridge import LambdaToEventbridge
+from aws_cdk import (
+    aws_lambda as _lambda,
+    Stack
+)
+from constructs import Construct
+
+LambdaToEventbridge(self, 'LambdaToEventbridgePattern',
+                    lambda_function_props=_lambda.FunctionProps(
+                        code=_lambda.Code.from_asset('lambda'),
+                        runtime=_lambda.Runtime.PYTHON_3_9,
+                        handler='index.handler'
+                    )
+                    )
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`LambdaToEventbridgeProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awscdk.services.lambda.*;
+import software.amazon.awscdk.services.lambda.Runtime;
+import software.amazon.awsconstructs.services.lambdaeventbridge.*;
+
+new LambdaToEventbridge(this, "LambdaToEventbridgePattern", new LambdaToEventbridgeProps.Builder()
+        .lambdaFunctionProps(new FunctionProps.Builder()
+                .runtime(Runtime.NODEJS_14_X)
+                .code(Code.fromAsset("lambda"))
+                .handler("index.handler")
+                .build())
+        .build());
+```
 
 ## Pattern Construct Props
 
@@ -63,7 +95,7 @@ new LambdaToEventbridge(scope: Construct, id: string, props: LambdaToEventbridge
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon EventBridge. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
 |vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
-|eventBusEnvironmentVariableName?|`string`|Optional Name for the EventBus's name environment variable set for the Lambda function.|
+|eventBusEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the name of the Event bus. Default: EVENTBUS_NAME |
 
 ## Pattern Properties
 
@@ -95,7 +127,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -142,7 +174,7 @@ class LambdaToEventbridge(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param event_bus_environment_variable_name: Optional Name for the EventBus's name environment variable set for the Lambda function. Default: - EVENTBUS_NAME is used
+        :param event_bus_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the Event bus. Default: - EVENTBUS_NAME
         :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
         :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
@@ -212,7 +244,7 @@ class LambdaToEventbridgeProps:
     ) -> None:
         '''
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param event_bus_environment_variable_name: Optional Name for the EventBus's name environment variable set for the Lambda function. Default: - EVENTBUS_NAME is used
+        :param event_bus_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the Event bus. Default: - EVENTBUS_NAME
         :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
         :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
@@ -257,9 +289,9 @@ class LambdaToEventbridgeProps:
 
     @builtins.property
     def event_bus_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the EventBus's name environment variable set for the Lambda function.
+        '''Optional Name for the Lambda function environment variable set to the name of the Event bus.
 
-        :default: - EVENTBUS_NAME is used
+        :default: - EVENTBUS_NAME
         '''
         result = self._values.get("event_bus_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
